@@ -2,13 +2,14 @@ import itertools
 import warnings
 from functools import lru_cache
 from os import environ
-from typing import List, Optional, Tuple, Union
+from typing import List, Optional, Tuple, Union, Dict
 from typing_extensions import Literal
 
 from emmet.core.mpid import MPID
 from emmet.core.settings import EmmetSettings
 from emmet.core.symmetry import CrystalSystem
 from emmet.core.vasp.calc_types import CalcType
+from emmet.core.summary import HasProps
 from mpcontribs.client import Client
 from pymatgen.analysis.magnetism import Ordering
 from pymatgen.analysis.phase_diagram import PhaseDiagram
@@ -532,10 +533,7 @@ class MPRester:
 
         return pbx_entries
 
-    # TODO - @lru_cache causes this method to fail when chemsys is given as a list,
-    # with an 'unhashable type' error
-    # @lru_cache
-    def get_ion_reference_data(self, chemsys: Union[str, List]) -> List[dict]:
+    def get_ion_reference_data(self, chemsys: Union[str, List]) -> List[Dict]:
         """
         Download aqueous ion reference data used in the construction of Pourbaix diagrams.
 
@@ -574,7 +572,14 @@ class MPRester:
         # capitalize and sort the elements
         chemsys = sorted(e.capitalize() for e in chemsys)
 
-        # TODO - see if there is a way to avoid querying the entire collection
+        # convert to a tuple which is hashable
+        return self._get_ion_reference_data(tuple(chemsys))  # type: ignore
+
+    @lru_cache()  # type: ignore
+    def _get_ion_reference_data(self, chemsys: Tuple):  # type: ignore
+        """
+        Private, cacheable helper method for get_ion_reference data.
+        """
         ion_data = [
             d
             for d in self.contribs.contributions.get_entries(
@@ -845,7 +850,7 @@ class MPRester:
         surface_energy_anisotropy: Optional[Tuple[float, float]] = None,
         shape_factor: Optional[Tuple[float, float]] = None,
         has_reconstructed: Optional[bool] = None,
-        has_props: Optional[List[str]] = None,
+        has_props: Optional[List[HasProps]] = None,
         theoretical: Optional[bool] = None,
         sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
@@ -918,7 +923,7 @@ class MPRester:
                 consider.
             shape_factor (Tuple[float,float]): Minimum and maximum shape factor values to consider.
             has_reconstructed (bool): Whether the entry has any reconstructed surfaces.
-            has_props: (List[str]): The calculated properties available for the material.
+            has_props: (List[HasProps]): The calculated properties available for the material.
             theoretical: (bool): Whether the material is theoretical.
             sort_fields (List[str]): Fields used to sort results. Prefixing with '-' will sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
