@@ -12,9 +12,7 @@ class GeneralStoreRester(BaseRester[GeneralStoreDoc]):  # pragma: no cover
     monty_decode = False
     use_document_model = False
 
-    def set_user_settings(
-        self, kind: str, markdown: str, meta: Dict
-    ):  # pragma: no cover
+    def add_item(self, kind: str, markdown: str, meta: Dict):  # pragma: no cover
         """
         Set general store data.
         Args:
@@ -30,7 +28,7 @@ class GeneralStoreRester(BaseRester[GeneralStoreDoc]):  # pragma: no cover
             body=meta, params={"kind": kind, "markdown": markdown}
         ).get("data")
 
-    def get_data(self, kind):  # pragma: no cover
+    def get_items(self, kind):  # pragma: no cover
         """
         Get general store data.
         Args:
