@@ -23,8 +23,7 @@ class ElasticityRester(BaseRester[ElasticityDoc]):
         g_vrh: Optional[Tuple[float, float]] = None,
         elastic_anisotropy: Optional[Tuple[float, float]] = None,
         poisson_ratio: Optional[Tuple[float, float]] = None,
-        sort_field: Optional[str] = None,
-        ascending: Optional[bool] = None,
+        sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
@@ -50,8 +49,7 @@ class ElasticityRester(BaseRester[ElasticityDoc]):
                 the elastic anisotropy.
             poisson_ratio (Tuple[float,float]): Minimum and maximum value to consider for
                 Poisson's ratio.
-            sort_field (str): Field used to sort results.
-            ascending (bool): Whether sorting should be in ascending order.
+            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -95,11 +93,10 @@ class ElasticityRester(BaseRester[ElasticityDoc]):
                 {"poisson_min": poisson_ratio[0], "poisson_max": poisson_ratio[1]}
             )
 
-        if sort_field:
-            query_params.update({"sort_field": sort_field})
-
-        if ascending is not None:
-            query_params.update({"ascending": ascending})
+        if sort_fields:
+            query_params.update(
+                {"sort_fields": ",".join([s.strip() for s in sort_fields])}
+            )
 
         query_params = {
             entry: query_params[entry]
