@@ -21,8 +21,7 @@ class ElectronicStructureRester(BaseRester[ElectronicStructureDoc]):
         magnetic_ordering: Optional[Ordering] = None,
         is_gap_direct: bool = None,
         is_metal: bool = None,
-        sort_field: Optional[str] = None,
-        ascending: Optional[bool] = None,
+        sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
@@ -37,8 +36,7 @@ class ElectronicStructureRester(BaseRester[ElectronicStructureDoc]):
             magnetic_ordering (Ordering): Magnetic ordering of the material.
             is_gap_direct (bool): Whether the material has a direct band gap.
             is_metal (bool): Whether the material is considered a metal.
-            sort_field (str): Field used to sort results.
-            ascending (bool): Whether sorting should be in ascending order.
+            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -68,11 +66,10 @@ class ElectronicStructureRester(BaseRester[ElectronicStructureDoc]):
         if is_metal is not None:
             query_params.update({"is_metal": is_metal})
 
-        if sort_field:
-            query_params.update({"sort_field": sort_field})
-
-        if ascending is not None:
-            query_params.update({"ascending": ascending})
+        if sort_fields:
+            query_params.update(
+                {"sort_fields": ",".join([s.strip() for s in sort_fields])}
+            )
 
         query_params = {
             entry: query_params[entry]
@@ -102,8 +99,7 @@ class BandStructureRester(BaseRester):
         magnetic_ordering: Optional[Ordering] = None,
         is_gap_direct: bool = None,
         is_metal: bool = None,
-        sort_field: Optional[str] = None,
-        ascending: Optional[bool] = None,
+        sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
@@ -119,8 +115,7 @@ class BandStructureRester(BaseRester):
             magnetic_ordering (Ordering): Magnetic ordering of the material.
             is_gap_direct (bool): Whether the material has a direct band gap.
             is_metal (bool): Whether the material is considered a metal.
-            sort_field (str): Field used to sort results.
-            ascending (bool): Whether sorting should be in ascending order.
+            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -152,11 +147,10 @@ class BandStructureRester(BaseRester):
         if is_metal is not None:
             query_params.update({"is_metal": is_metal})
 
-        if sort_field:
-            query_params.update({"sort_field": sort_field})
-
-        if ascending is not None:
-            query_params.update({"ascending": ascending})
+        if sort_fields:
+            query_params.update(
+                {"sort_fields": ",".join([s.strip() for s in sort_fields])}
+            )
 
         query_params = {
             entry: query_params[entry]
