@@ -15,8 +15,7 @@ class EOSRester(BaseRester[EOSDoc]):
         self,
         volumes: Optional[Tuple[float, float]] = None,
         energies: Optional[Tuple[float, float]] = None,
-        sort_field: Optional[str] = None,
-        ascending: Optional[bool] = None,
+        sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
@@ -28,8 +27,7 @@ class EOSRester(BaseRester[EOSDoc]):
         Arguments:
             volumes (Tuple[float,float]): Minimum and maximum volume in A³/atom to consider for EOS plot range.
             energies (Tuple[float,float]): Minimum and maximum energy in eV/atom to consider for EOS plot range.
-            sort_field (str): Field used to sort results.
-            ascending (bool): Whether sorting should be in ascending order.
+            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -50,11 +48,10 @@ class EOSRester(BaseRester[EOSDoc]):
                 {"energies_min": energies[0], "energies_max": energies[1]}
             )
 
-        if sort_field:
-            query_params.update({"sort_field": sort_field})
-
-        if ascending is not None:
-            query_params.update({"ascending": ascending})
+        if sort_fields:
+            query_params.update(
+                {"sort_fields": ",".join([s.strip() for s in sort_fields])}
+            )
 
         query_params = {
             entry: query_params[entry]
