@@ -9,10 +9,11 @@ def similarity_resource(similarity_store):
         SimilarityDoc,
         query_operators=[
             PaginationQuery(),
-            SparseFieldsQuery(SimilarityDoc, default_fields=["task_id"]),
+            SparseFieldsQuery(SimilarityDoc, default_fields=["material_id"]),
         ],
         tags=["Similarity"],
         enable_default_search=False,
+        disable_validation=True,
     )
 
     return resource
