@@ -21,8 +21,7 @@ class SubstratesRester(BaseRester[SubstratesDoc]):
         substrate_orientation: Optional[List[int]] = None,
         area: Optional[Tuple[float, float]] = None,
         energy: Optional[Tuple[float, float]] = None,
-        sort_field: Optional[str] = None,
-        ascending: Optional[bool] = None,
+        sort_fields: Optional[List[str]] = None,
         num_chunks: Optional[int] = None,
         chunk_size: int = 1000,
         all_fields: bool = True,
@@ -40,8 +39,7 @@ class SubstratesRester(BaseRester[SubstratesDoc]):
             area (Tuple[float,float]): Minimum and maximum volume in Å² to consider for the minimim coincident
                 interface area range.
             energy (Tuple[float,float]): Minimum and maximum energy in meV to consider for the elastic energy range.
-            sort_field (str): Field used to sort results.
-            ascending (bool): Whether sorting should be in ascending order.
+            sort_fields (List[str]): Fields used to sort results. Prefix with '-' to sort in descending order.
             num_chunks (int): Maximum number of chunks of data to yield. None will yield all possible.
             chunk_size (int): Number of data entries per chunk.
             all_fields (bool): Whether to return all fields in the document. Defaults to True.
@@ -83,11 +81,10 @@ class SubstratesRester(BaseRester[SubstratesDoc]):
         if energy:
             query_params.update({"energy_min": energy[0], "energy_max": energy[1]})
 
-        if sort_field:
-            query_params.update({"sort_field": sort_field})
-
-        if ascending is not None:
-            query_params.update({"ascending": ascending})
+        if sort_fields:
+            query_params.update(
+                {"sort_fields": ",".join([s.strip() for s in sort_fields])}
+            )
 
         query_params = {
             entry: query_params[entry]
