@@ -22,8 +22,9 @@ alt_name_dict = {"piezoelectric_modulus": "e_ij_max"}  # type: dict
 custom_field_tests = {}  # type: dict
 
 
-@pytest.mark.xfail(reason="Needs deployment")
-@pytest.mark.skipif(os.environ.get("MP_API_KEY", None) is None, reason="No API key found.")
+@pytest.mark.skipif(
+    os.environ.get("MP_API_KEY", None) is None, reason="No API key found."
+)
 @pytest.mark.parametrize("rester", resters)
 def test_client(rester):
     # Get specific search method
@@ -77,4 +78,7 @@ def test_client(rester):
                     if sub_field in doc:
                         doc = doc[sub_field]
 
-                assert doc[project_field if project_field is not None else param] is not None
+                assert (
+                    doc[project_field if project_field is not None else param]
+                    is not None
+                )
